@@ -606,7 +606,7 @@ class pyGRID:
 def main():
     # define the arguments for the python script
     parser = argparse.ArgumentParser()
-    parser.add_argument("-f", "--file",help="Specify which file pyGRID should use to load definitions of the simulations")
+    parser.add_argument("file",help="Specify which file pyGRID should use to load definitions of the simulations")
     
     simulation_group = parser.add_mutually_exclusive_group()
     simulation_group.add_argument("-s", "--simulation",help="The name of the simulation to use")
